| lpr_cc | R Documentation |
This function creates dataframes which can then be input in lapop_cc for comparing values across countries with a bar graph using LAPOP formatting.
lpr_cc(
data,
outcome,
xvar = "pais_lab",
rec = list(c(1, 1)),
rec2 = list(c(1, 1)),
rec3 = list(c(1, 1)),
rec4 = list(c(1, 1)),
ci_level = 0.95,
mean = FALSE,
filesave = "",
cfmt = "",
sort = "y",
order = "hi-lo",
ttest = FALSE,
keep_nr = FALSE
)
data |
A survey object. The data that should be analyzed. |
outcome |
Outcome variable(s) of interest to be plotted across countries. It can handle a single variable across countries, or multiple variables instead of multiple countries. See examples below. |
xvar |
Grouping variable. Default: pais_lab. It can handle other variables grouping like year/wave. |
rec |
Numeric. The minimum and maximum values of the outcome variable that should be included in the numerator of the percentage. For example, if the variable is on a 1-7 scale and rec is c(5, 7), the function will show the percentage who chose an answer of 5, 6, 7 out of all valid answers. Default: c(1, 1). |
rec2 |
Numeric. Same as rec(). Default: c(1, 1). |
rec3 |
Numeric. Same as rec(). Default: c(1, 1). |
rec4 |
Numeric. Same as rec(). Default: c(1, 1). |
ci_level |
Numeric. Confidence interval level for estimates. Default: 0.95 |
mean |
Logical. If TRUE, will produce the mean of the variable rather than rescaling to percentage. Default: FALSE. |
filesave |
Character. Path and file name to save the dataframe as csv. |
cfmt |
changes the format of the numbers displayed above the bars. Uses sprintf string formatting syntax. Default is whole numbers for percentages and tenths place for means. |
sort |
Character. On what value the bars are sorted: the x or the y. Options are "y" (default; for the value of the outcome variable), "xv" (for the underlying values of the x variable), "xl" (for the labels of the x variable, i.e., alphabetical). |
order |
Character. How the bars should be sorted. Options are "hi-lo" (default) or "lo-hi". |
ttest |
Logical. If TRUE, will conduct pairwise t-tests for difference of means between all individual x levels and save them in attr(x, "t_test_results"). Default: FALSE. |
keep_nr |
Logical. If TRUE, will convert "don't know" (missing code .a) and "no response" (missing code .b) into valid data (value = 99) and use them in the denominator when calculating percentages. The default is to examine valid responses only. Default: FALSE. |
Returns a data frame, with data formatted for visualization by lapop_cc
Luke Plutowski, luke.plutowski@vanderbilt.edu & Robert Vidigal, robert.vidigal@vanderbilt.edu
require(lapop); data(ym23); data(bra23)
# Set Survey Context on a small cross-country subset
ym23_small <- subset(ym23, pais %in% c(1, 15, 17))
ym23lpr <- lpr_data(ym23_small)
# Single variable in Multiple Countries
lpr_cc(data = ym23lpr,
outcome = "ing4",
rec = c(5, 7),
xvar = "pais")
# Multiple variables in Single Country
bra23lpr <- lpr_data(bra23, wt = TRUE)
lpr_cc(data = bra23lpr,
outcome = c("b12", "b13"),
rec = c(5, 7))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.