| lpr_data | R Documentation |
This function takes LAPOP datasets and adds survey features such as sampling design effects, outputting a svy_tbl object that can then be analyzed using lpr_ wrangling commands.
lpr_data(data_path, wt = FALSE)
data_path |
The path for a AmericasBarometer data or a an existing dataframe. |
wt |
Logical. If TRUE, use 'wt' (weights only for single-country single-year data) instead of 'weight1500' (the default weights for multiple-country and multiple-year data). Default: FALSE. |
Returns a svy_tbl object
Luke Plutowski, luke.plutowski@vanderbilt.edu & Robert Vidigal, robert.vidigal@vanderbilt.edu
data(bra23)
data(cm23)
bra23w <- lpr_data(bra23, wt = TRUE)
cm23w <- lpr_data(cm23)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.