Extract Stata variable notes and characteristics
lpr_extract_notes.RdReturns the original characteristic identifiers, without assuming that a particular note number is a question or that a variable label is a wording.
Value
A data frame with character columns `variable_name`, `note_id`, and `note_value`. These columns are also present when no notes are available.
Examples
toy <- data.frame(x = 1)
attr(toy, "expansion.fields") <- list(c("x", "note1", "Question?"))
lpr_extract_notes(toy)
#> variable_name note_id note_value
#> 1 x note1 Question?